Module: Disqualified
- Defined in:
- lib/disqualified.rb,
lib/disqualified/error.rb,
lib/disqualified/engine.rb,
lib/disqualified/version.rb,
lib/disqualified/configuration.rb
Defined Under Namespace
Modules: Error, Job, Logging Classes: ActiveJobAdapter, BaseRecord, CLI, ClientConfiguration, Engine, InstallGenerator, Main, Pool, Record, Sequence, SequenceRecord, ServerConfiguration
Constant Summary collapse
- VERSION =
"0.5.1"
Class Attribute Summary collapse
-
.client_options ⇒ Object
Returns the value of attribute client_options.
-
.server_options ⇒ Object
Returns the value of attribute server_options.
Class Method Summary collapse
- .configure_client(&block) ⇒ Object
-
.configure_server(&block) ⇒ Object
While client options are always run, server options only run in the "disqualified" process.
Class Attribute Details
.client_options ⇒ Object
Returns the value of attribute client_options.
5 6 7 |
# File 'lib/disqualified/configuration.rb', line 5 def @client_options end |
.server_options ⇒ Object
Returns the value of attribute server_options.
7 8 9 |
# File 'lib/disqualified/configuration.rb', line 7 def @server_options end |
Class Method Details
.configure_client(&block) ⇒ Object
9 10 11 |
# File 'lib/disqualified/configuration.rb', line 9 def configure_client(&block) block.call() end |
.configure_server(&block) ⇒ Object
While client options are always run, server options only run in the "disqualified" process
15 16 17 18 19 |
# File 'lib/disqualified/configuration.rb', line 15 def configure_server(&block) if block.call() end end |